@@ -13,7 +13,14 @@ This library can be installed using pip:
 
     pip install quantimpy
 
+If you use this package in your research, please cite it as:
+
+Arnout M.P. Boelens, and Hamdi A. Tchelepi, *QuantImPy: Minkowski functionals
+and functions with Python*, SoftwareX, Volume 16, 2021, 100823, ISSN 2352-7110,
+doi: `10.1016/j.softx.2021.100823`_,
+
 .. _QuantIm library: https://www.ufz.de/index.php?en=39198
 .. _Github: https://github.com/boeleman/quantimpy
+.. _10.1016/j.softx.2021.100823: https://doi.org/10.1016/j.softx.2021.100823
 
 """
